#!/usr/bin/env python
# -*- coding: utf-8 -*-

import datetime
import os
import platform
import shlex

from linux import base
from linux.base import b
from modules.module_base import ModuleBase

bool_close_fds = False if platform.system().lower() == 'windows' else True


def run(args):
    '''Write the result to a json file'''
    module = ModuleBase(
        argument_spec=dict(
            command=dict(),
            _uses_shell=dict(type='bool', default=True),
            chdir=dict(type='path'),
            executable=dict(),
        ))

    rc_flag, value = module.load_params(args)
    if rc_flag != 0:
        return module.fail_json(rc_flag=256, msg=value)

    command = module.params.get('command')
    shell = module.params.get('_uses_shell')
    chdir = module.params.get('chdir')
    executable = module.params.get('executable')

    if command.strip() == '':
        return module.fail_json(rc_flag=256, msg="no command given")

    if not shell:
        command = shlex.split(command)

    if chdir:
        chdir = os.path.abspath(chdir)
        os.chdir(chdir)

    ret, rc_flag, out, err = base.run_command(command, check_rc=False,
                                         close_fds=bool_close_fds,
                                         executable=executable)

    if ret != 0:
        return module.fail_json(rc_flag=256,
                                msg="failed to run command, rc_flag = %s out = %s err = %s" % (
                                rc_flag, out, err))

    start_time = datetime.datetime.now()
    end_time = datetime.datetime.now()
    interval_time = end_time - start_time

    if out is None:
        out = b('')
    out = out.rstrip("\r\n")

    if err is None:
        err = b('')
    err = err.rstrip("\r\n")

    return module.exit_json(
        cmd=command,
        stdout=out,
        stderr=err,
        rc_flag=rc_flag,
        start=str(start_time),
        end=str(end_time),
        delta=str(interval_time),
        changed=True
    )
